@@ -2,13 +2,15 @@ import re
 from enum import Enum
 from typing import Any, Dict
 
-from .enums import AltEvoSort, CardPlusModifier, ChildMenuType, EvoGrouping, EvoToFocus, LsMultiplier, Server
+from tsutils.enums import Server, EvoToFocus, AltEvoSort, ChildMenuType, LsMultiplier, CardPlusModifier, \
+    EvoGrouping, CardModeModifier, CardLevelModifier
 
 SETTINGS_REGEX = re.compile(r'(?:--|—)(\w+)(?::{(.+?)})?')
 
 
 class QuerySettings:
-    SERIALIZED_VALUES = ['server', 'evosort', 'child_menu_type', 'lsmultiplier', 'cardplus', 'evogrouping']
+    SERIALIZED_VALUES = ['server', 'evosort', 'child_menu_type', 'lsmultiplier', 'cardplus', 'evogrouping',
+                         'cardmode', 'cardlevel']
     NAMES_TO_ENUMS = {
         'na_prio': EvoToFocus,
         'server': Server,
@@ -17,6 +19,8 @@ class QuerySettings:
         'lsmultiplier': LsMultiplier,
         'cardplus': CardPlusModifier,
         'evogrouping': EvoGrouping,
+        'cardmode': CardModeModifier,
+        'cardlevel': CardLevelModifier,
     }
     ENUMS_TO_NAMES = {v: k for k, v in NAMES_TO_ENUMS.items()}
     SETTINGS_TO_ENUMS = {
@@ -35,7 +39,15 @@ class QuerySettings:
         'plus297': CardPlusModifier.plus297,
         'splitevos': EvoGrouping.splitevos,
         'groupevos': EvoGrouping.groupevos,
+        'solo': CardModeModifier.solo,
+        'coop': CardModeModifier.coop,
+        'lvmax': CardLevelModifier.lvmax,
+        'lv110': CardLevelModifier.lv110,
+        'lv120': CardLevelModifier.lv120,
     }
+    SETTINGS_WITH_DATA_NAMES = [
+        'level',
+    ]
 
     def __init__(self,
                  na_prio: EvoToFocus = EvoToFocus.naprio,
@@ -45,6 +57,8 @@ class QuerySettings:
                  lsmultiplier: LsMultiplier = LsMultiplier.lsdouble,
                  cardplus: CardPlusModifier = CardPlusModifier.plus297,
                  evogrouping: EvoGrouping = EvoGrouping.splitevos,
+                 cardmode: CardModeModifier = CardPlusModifier.solo,
+                 cardlevel: CardLevelModifier = CardLevelModifier.lvmax,
                  ):
         self.na_prio = na_prio
         self.server = server
@@ -53,6 +67,8 @@ class QuerySettings:
         self.lsmultiplier = lsmultiplier
         self.cardplus = cardplus
         self.evogrouping = evogrouping
+        self.cardmode = cardmode
+        self.cardlevel = cardlevel
 
     @classmethod
     def extract(cls, fm_flags: Dict[str, Any], query: str) -> "QuerySettings":
@@ -62,12 +78,12 @@ class QuerySettings:
                 fm_flags[key] = QuerySettings.NAMES_TO_ENUMS[key](value)  # noqa
 
         for setting, data in re.findall(SETTINGS_REGEX, query.lower()):
-            if setting not in cls.SETTINGS_TO_ENUMS:
-                continue
-            value = cls.SETTINGS_TO_ENUMS[setting]
-            key = cls.ENUMS_TO_NAMES[type(value)]
-            fm_flags[key] = value
-
+            if setting in cls.SETTINGS_TO_ENUMS:
+                value = cls.SETTINGS_TO_ENUMS[setting]
+                key = cls.ENUMS_TO_NAMES[type(value)]
+                fm_flags[key] = value
+            elif setting in cls.SETTINGS_WITH_DATA_NAMES:
+                fm_flags[setting] = data
         return QuerySettings(**fm_flags)
 
     def serialize(self: "QuerySettings") -> Dict[str, Any]:
